﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Data;

namespace App
{
    /// <summary>
    /// Formulář pro přidání nové faktury (Invoice)
    /// </summary>
    public partial class InvoiceAdd : Form
    {
        private Invoice inv;
        private Boolean error = false;
        private List<String> errMsg = new List<string>();

        /// <summary>
        /// Konstruktor, inicializace komponenty a načtení hodnot do ComboBoxů a CheckedListu
        /// </summary>
        public InvoiceAdd()
        {
            this.inv = new Invoice(123);
            InitializeComponent();

            foreach (Person p in Core.people)
                invoiceCtrl1.ComboSupplier.Items.Add(p.Name + " " + p.Surname);
            foreach (Person p in Core.people)
                invoiceCtrl1.ComboSubscriber.Items.Add(p.Name + " " + p.Surname);
            foreach (Item it in Core.items)
            {
                invoiceCtrl1.CheckedListBoxInv.Items.Add(it);
            }
        }

        /// <summary>
        /// Metoda zkontroluje jestli nové ID nemá již nějaká jiná faktura.
        /// <param name="id">Integer</param>
        /// </summary>
        private bool checkId(int id)
        {
            foreach (Invoice invoice in Core.invoices)
            {
                if (invoice.ID == id)
                {
                    MessageBox.Show("Faktura s tímto ID již existuje.");
                    return false;
                }
            }
            return true;
        }

        /// <summary>
        /// Uzavře formulář bez uložení dat, klávesová zkratka ESC.
        /// </summary>
        /// <param name="sender">object</param>
        /// <param name="e">EventArgs</param>
        private void buttonCancel_Click_1(object sender, EventArgs e)
        {
            Close();
        }

        /// <summary>
        /// Klávesové zkratky pro práci s formulářem.
        /// ENTER = uložit
        /// ESC = zavřít
        /// </summary>
        /// <param name="sender">object</param>
        /// <param name="e">KeyEventArgs</param>
        public void KeyUpEvent(object sender, KeyEventArgs e) //aby to fungovalo musí se u okna zapnout KeyPreview!!!
        {
            switch (e.KeyCode)
            {
                case Keys.Enter:
                    buttonOk.PerformClick();
                    break;

                case Keys.Escape:
                    buttonCancel.PerformClick();
                    break;

                default:
                    break;
            }
        }

        /// <summary>
        /// Uložení nové faktury v programu. Klávesová zkratka ENTER.
        /// </summary>
        /// <param name="sender">object</param>
        /// <param name="e">EventArgs</param>
        private void buttonOk_Click(object sender, EventArgs e)
        {
            if (invoiceCtrl1.TextBoxId.Text != "" && checkId(int.Parse(invoiceCtrl1.TextBoxId.Text)))
            {
                inv.ID = int.Parse(invoiceCtrl1.TextBoxId.Text);

                if (invoiceCtrl1.TextBoxType.Text != "" && (
                    invoiceCtrl1.TextBoxType.Text.CompareTo("Přijatá") == 0 ||
                    invoiceCtrl1.TextBoxType.Text.CompareTo("Vydaná") == 0))
                {
                    inv.Name = invoiceCtrl1.TextBoxType.Text;
                }
                else
                {
                    error = true;
                    errMsg.Add("Typ musí být vyplněn a může nabívat pouze hodnot:\n\"Přijatá\" nebo \"Vydaná\"");
                }


                if (invoiceCtrl1.ComboSupplier.Text != "")
                {
                    foreach (Person p in Core.people)
                    {
                        if (invoiceCtrl1.ComboSupplier.Text.CompareTo(p.Name + " " + p.Surname) == 0)
                        {
                            inv.Supplier = p;
                        }
                    }
                }
                else
                {
                    error = true;
                    errMsg.Add("Přijmení nemůže být prázdné");
                }

                if (invoiceCtrl1.ComboSubscriber.Text != "")
                {
                    foreach (Person p in Core.people)
                    {
                        if (invoiceCtrl1.ComboSubscriber.Text.CompareTo(p.Name + " " + p.Surname) == 0)
                        {
                            inv.Subscriber = p;
                        }
                    }
                }
                else
                {
                    error = true;
                    errMsg.Add("Přijmení nemůže být prázdné");
                }

                inv.Paid = invoiceCtrl1.CheckBoxPaid.Checked;
                inv.Created = DateTime.Parse(invoiceCtrl1.DateTimeCreated.Text);
                inv.DueDays = int.Parse(invoiceCtrl1.TextBoxDueDays.Text);

                foreach(Item item in invoiceCtrl1.CheckedListBoxInv.CheckedItems)
                {
                    inv.addItem(item);
                }


                if (error)
                {
                    string str = "";
                    foreach (String s in errMsg)
                    {
                        str += s + "\n";
                        errMsg.Remove(s);
                    }
                    MessageBox.Show(str);
                    error = false;
                }
                else
                {
                    Core.invoices.Add(inv);
                    Close();
                }
            }
            else
            {
                MessageBox.Show("Nesprávně zadné ID");
            }
        }
    }
}
